@@ -428,6 +428,10 @@ class BaseSim(ParsObj):
         for key,res in self.results.items():
             if isinstance(res, Result):
                 resdict[key] = res.values
+                if res.low is not None:
+                    resdict[key+'_low'] = res.low
+                if res.high is not None:
+                    resdict[key+'_high'] = res.high
             elif for_json:
                 if key == 'date':
                     resdict[key] = [str(d) for d in res] # Convert dates to strings
@@ -1105,7 +1109,12 @@ class BasePeople(FlexPretty):
 
             # Create the layer if it doesn't yet exist
             if lkey not in self.contacts:
-                self.contacts[lkey] = Layer()
+                if self.pars['dynam_layer'].get(lkey, False):
+                    # Equivalent to previous functionality, but might be better if make_randpop() returned Layer objects instead of just dicts, that
+                    # way the population creation function could have control over both the contacts and the update algorithm
+                    self.contacts[lkey] = RandomLayer()
+                else:
+                    self.contacts[lkey] = Layer()
 
             # Actually include them, and update properties if supplied
             for col in self.contacts[lkey].keys(): # Loop over the supplied columns
@@ -1270,7 +1279,41 @@ class Contacts(FlexDict):
 
 
 class Layer(FlexDict):
-    ''' A small class holding a single layer of contacts '''
+    '''
+    A small class holding a single layer of contact edges (connections) between people.
+
+    The input is typically three arrays: person 1 of the connection, person 2 of
+    the connection, and the weight of the connection. Connections are undirected;
+    each person is both a source and sink.
+
+    This class is usually not invoked directly by the user, but instead is called
+    as part of the population creation.
+
+    Args:
+        p1 (array): an array of N connections, representing people on one side of the connection
+        p2 (array): an array of people on the other side of the connection
+        beta (array): an array of weights for each connection
+        kwargs (dict): other keys copied directly into the layer
+
+    Note that all arguments must be arrays of the same length, although not all
+    have to be supplied at the time of creation (they must all be the same at the
+    time of initialization, though, or else validation will fail).
+
+    **Examples**::
+
+        # Generate an average of 10 contacts for 1000 people
+        n = 10_000
+        n_people = 1000
+        p1 = np.random.randint(n_people, size=n)
+        p2 = np.random.randint(n_people, size=n)
+        beta = np.ones(n)
+        layer = cv.Layer(p1=p1, p2=p2, beta=beta)
+
+        # Convert one layer to another with an extra column
+        index = np.arange(n)
+        self_conn = p1 == p2
+        layer2 = cv.Layer(**layer, index=index, self_conn=self_conn)
+    '''
 
     def __init__(self, **kwargs):
         self.meta = {
@@ -1286,7 +1329,7 @@ class Layer(FlexDict):
 
         # Set data, if provided
         for key,value in kwargs.items():
-            self[key] = np.array(value, dtype=self.meta[key])
+            self[key] = np.array(value, dtype=self.meta.get(key))
 
         return
 
@@ -1300,8 +1343,9 @@ class Layer(FlexDict):
 
     def __repr__(self):
         ''' Convert to a dataframe for printing '''
+        label = self.__class__.__name__
         keys_str = ', '.join(self.keys())
-        output = f'Layer({keys_str})\n'
+        output = f'{label}({keys_str})\n' # e.g. Layer(p1, p2, beta)
         output += self.to_df().__repr__()
         return output
 
@@ -1432,3 +1476,33 @@ class Layer(FlexDict):
             contact_inds.sort()  # Sorting ensures that the results are reproducible for a given seed as well as being identical to previous versions of Covasim
 
         return contact_inds
+
+
+    def update(self, people, frac=1.0):
+        '''
+        Regenerate contacts on each timestep.
+
+        This method gets called if the layer appears in ``sim.pars['dynam_lkeys']``.
+        The Layer implements the update procedure so that derived classes can customize
+        the update e.g. implementing over-dispersion/other distributions, random
+        clusters, etc.
+
+        Typically, this method also takes in the ``people`` object so that the
+        update can depend on person attributes that may change over time (e.g.
+        changing contacts for people that are severe/critical).
+
+        Args:
+            frac (float): the fraction of contacts to update on each timestep
+        '''
+        # Choose how many contacts to make
+        pop_size   = len(people) # Total number of people
+        n_contacts = len(self) # Total number of contacts
+        n_new = int(np.round(n_contacts*frac)) # Since these get looped over in both directions later
+        inds = cvu.choose(n_contacts, n_new)
+
+        # Create the contacts, not skipping self-connections
+        self['p1'][inds]   = np.array(cvu.choose_r(max_n=pop_size, n=n_new), dtype=cvd.default_int) # Choose with replacement
+        self['p2'][inds]   = np.array(cvu.choose_r(max_n=pop_size, n=n_new), dtype=cvd.default_int)
+        self['beta'][inds] = np.ones(n_new, dtype=cvd.default_float)
+        return
+
