@@ -7,6 +7,7 @@ import pandas as pd
 import pylab as pl
 import sciris as sc
 import scipy.stats as sps
+from pathlib import Path
 from . import version as cvv
 
 
@@ -25,7 +26,7 @@ date_range = sc.daterange
 __all__ += ['load_data', 'load', 'save', 'migrate', 'savefig']
 
 
-def load_data(datafile, columns=None, calculate=True, check_date=True, verbose=True, **kwargs):
+def load_data(datafile, columns=None, calculate=True, check_date=True, verbose=True, start_day=None, **kwargs):
     '''
     Load data for comparing to the model output, either from file or from a dataframe.
 
@@ -34,6 +35,7 @@ def load_data(datafile, columns=None, calculate=True, check_date=True, verbose=T
         columns (list): list of column names (otherwise, load all)
         calculate (bool): whether to calculate cumulative values from daily counts
         check_date (bool): whether to check that a 'date' column is present
+        start_day (date): if the 'date' column is provided as integer number of days, consider them relative to this
         kwargs (dict): passed to pd.read_excel()
 
     Returns:
@@ -41,6 +43,8 @@ def load_data(datafile, columns=None, calculate=True, check_date=True, verbose=T
     '''
 
     # Load data
+    if isinstance(datafile, Path): # Convert to a string
+        datafile = str(datafile)
     if isinstance(datafile, str):
         df_lower = datafile.lower()
         if df_lower.endswith('csv'):
@@ -85,13 +89,16 @@ def load_data(datafile, columns=None, calculate=True, check_date=True, verbose=T
             errormsg = f'Required column "date" not found; columns are {data.columns}'
             raise ValueError(errormsg)
         else:
-            data['date'] = pd.to_datetime(data['date']).dt.date
+            if data['date'].dtype == np.int64: # If it's integers, treat it as days from the start day
+                data['date'] = sc.date(data['date'].values, start_date=start_day)
+            else: # Otherwise, use Pandas to convert it
+                data['date'] = pd.to_datetime(data['date']).dt.date
         data.set_index('date', inplace=True, drop=False) # Don't drop so sim.data['date'] can still be accessed
 
     return data
 
 
-def load(*args, do_migrate=True, **kwargs):
+def load(*args, do_migrate=True, update=True, verbose=True, **kwargs):
     '''
     Convenience method for sc.loadobj() and equivalent to cv.Sim.load() or
     cv.Scenarios.load().
@@ -99,6 +106,8 @@ def load(*args, do_migrate=True, **kwargs):
     Args:
         filename (str): file to load
         do_migrate (bool): whether to migrate if loading an old object
+        update (bool): whether to modify the object to reflect the new version
+        verbose (bool): whether to print migration information
         args (list): passed to sc.loadobj()
         kwargs (dict): passed to sc.loadobj()
 
@@ -118,7 +127,7 @@ def load(*args, do_migrate=True, **kwargs):
         if cmp != 0:
             print(f'Note: you have Covasim v{v_curr}, but are loading an object from v{v_obj}')
             if do_migrate:
-                obj = migrate(obj, v_obj, v_curr)
+                obj = migrate(obj, update=update, verbose=verbose)
     return obj
 
 
@@ -145,6 +154,43 @@ def save(*args, **kwargs):
     return filepath
 
 
+def migrate_lognormal(pars, revert=False, verbose=True):
+    '''
+    Small helper function to automatically migrate the standard deviation of lognormal
+    distributions to match pre-v2.1.0 runs (where it was treated as the variance instead).
+    To undo the migration, run with revert=True.
+
+    Args:
+        pars (dict): the parameters dictionary; or, alternatively, the sim object the parameters will be taken from
+        revert (bool): whether to reverse the update rather than make it
+        verbose (bool): whether to print out the old and new values
+    '''
+    # Handle different input types
+    from . import base as cvb
+    if isinstance(pars, cvb.BaseSim):
+        pars = pars.pars # It's actually a sim, not a pars object
+
+    # Convert each value to the square root, since squared in the new version
+    for key,dur in pars['dur'].items():
+        if 'lognormal' in dur['dist']:
+            old = dur['par2']
+            if revert:
+                new = old**2
+            else:
+                new = np.sqrt(old)
+            dur['par2'] = new
+            if verbose > 1:
+                print(f'  Updating {key} std from {old:0.2f} to {new:0.2f}')
+
+    # Store whether migration has occurred so we don't accidentally do it twice
+    if not revert:
+        pars['migrated_lognormal'] = True
+    else:
+        pars.pop('migrated_lognormal', None)
+
+    return
+
+
 def migrate(obj, update=True, verbose=True, die=False):
     '''
     Define migrations allowing compatibility between different versions of saved
@@ -167,6 +213,7 @@ def migrate(obj, update=True, verbose=True, die=False):
         sims = cv.load('my-list-of-sims.obj')
         sims = [cv.migrate(sim) for sim in sims]
     '''
+    # Import here to avoid recursion
     from . import base as cvb
     from . import run as cvr
     from . import interventions as cvi
@@ -196,6 +243,13 @@ def migrate(obj, update=True, verbose=True, die=False):
                 except:
                     pass
 
+        # Migration from <2.1.0 to 2.1.0
+        if sc.compareversions(sim.version, '2.1.0') == -1: # Migrate from <2.0 to 2.0
+            if verbose:
+                print(f'Migrating sim from version {sim.version} to version {cvv.__version__}')
+                print('Note: updating lognormal stds to restore previous behavior; see v2.1.0 changelog for details')
+            migrate_lognormal(sim.pars, verbose=verbose)
+
     # Migrations for People
     elif isinstance(obj, cvb.BasePeople): # pragma: no cover
         ppl = obj
