@@ -146,6 +146,11 @@ def set_option(key=None, value=None, **kwargs):
     return
 
 
+def get_default(key=None):
+    ''' Helper function to get the original default options '''
+    return orig_options[key]
+
+
 def get_help(output=False):
     '''
     Print information about options.
@@ -188,9 +193,9 @@ def set_matplotlib_global(key, value):
     ''' Set a global option for Matplotlib -- not for users '''
     import pylab as pl
     if value: # Don't try to reset any of these to a None value
-        if   key == 'font_size':   pl.rc('font', size=value)
-        elif key == 'font_family': pl.rc('font', family=value)
-        elif key == 'dpi':         pl.rc('figure', dpi=value)
+        if   key == 'font_size':   pl.rcParams['font.size']   = value
+        elif key == 'font_family': pl.rcParams['font.family'] = value
+        elif key == 'dpi':         pl.rcParams['figure.dpi']  = value
         elif key == 'backend':     pl.switch_backend(value)
         else: raise sc.KeyNotFoundError(f'Key {key} not found')
     return
@@ -232,4 +237,5 @@ def reload_numba():
 
 # Add these here to be more accessible to the user
 options.set = set_option
+options.get_default = get_default
 options.help = get_help
\ No newline at end of file
